@@ -30,6 +30,13 @@
 
 #include <stdio.h>
 #include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
+#include <sys/ioctl.h>
+#include <unistd.h>
+#include <termios.h>
+#include <term.h>
 #include "jered.h"
 #include "formulr.h"
 #include "mappable.h"
@@ -45,12 +52,43 @@ int resizewin = 0;
 int readakey_fromkeyboard(void);
 void restart_screen(int sig);
 /**********************************************************************/
+void getscreensize(void)
+{
+        struct winsize size;
+        
+        if (isatty(cur_term->Filedes))
+        {
+        
+                errno = 0;
+                do
+                {
+                        if ((ioctl(cur_term->Filedes, TIOCGWINSZ, &size) < 0) && (errno != EINTR))
+                                goto failure;
+                } 
+                while (errno == EINTR);
+        
+                JEREDLINES = (int)size.ws_row;
+                JEREDCOLS  = (int)size.ws_col;
+        }
+        else
+        {
+failure:        
+                JEREDLINES = LINES;
+                JEREDCOLS = COLS;
+        }
+        
+        XMAX = (JEREDCOLS - 1);
+        YMAX = (JEREDLINES - 2);
+}
+/**********************************************************************/
 void restart_screen(int sig)
 {
         if (inputmode == DIALOGMODE)
                 resizewin = 1;
         else
                 restart_screen_again();
+                
+        signal(SIGWINCH, restart_screen);
 }
 /**********************************************************************/
 void restart_screen_again(void)
@@ -78,8 +116,7 @@ void debute_ecran(void)
         firstcursor = allume_curseur(0);        /* sauve valeur du curseur et l'eteint */
         oldcursor = firstcursor;
 
-        XMAX = (COLS - 1);
-        YMAX = (LINES - 2);
+        getscreensize();
         
         signal(SIGWINCH, restart_screen);
 }
@@ -93,6 +130,7 @@ void termine_ecran(void)
 /**********************************************************************/
 int allume_curseur(int type)
 {
+        /* it seems that curs_set doesn't work like expected */
         oldcursor = curs_set(type);
         if (oldcursor == ERR)
                 oldcursor = 1;
@@ -101,6 +139,7 @@ int allume_curseur(int type)
 /**********************************************************************/
 void eteint_curseur(void)
 {
+        /* it seems that curs_set doesn't work like expected */
         oldcursor = curs_set(0);
         if (oldcursor == ERR)
                 oldcursor = 1;
@@ -108,6 +147,7 @@ void eteint_curseur(void)
 /**********************************************************************/
 void restaure_curseur(void)
 {
+        /* it seems that curs_set doesn't work like expected */
         oldcursor = curs_set(oldcursor);
         if (oldcursor == ERR)
                 oldcursor = 1;
@@ -139,8 +179,8 @@ int get_txt(int x, int y, int xmax, int ymax, chtype *dest)
         int sauvey;             /* sauve ordonnee */
         int lg;                 /* longueur */
 
-        xmax = min(xmax, (COLS - 1));
-        ymax = min(ymax, (LINES - 1));
+        xmax = min(xmax, (JEREDCOLS - 1));
+        ymax = min(ymax, (JEREDLINES - 1));
         if ((x > xmax) || (x < 0) || (y > ymax) || (y < 0))
                 return(-1);
         else
@@ -176,8 +216,8 @@ int put_txt(int x, int y, int xmax, int ymax, chtype *src)
         int sauvey;             /* sauve ordonnee */
         int lg;                 /* longueur */
 
-        xmax = min(xmax, (COLS - 1));
-        ymax = min(ymax, (LINES - 1));
+        xmax = min(xmax, (JEREDCOLS - 1));
+        ymax = min(ymax, (JEREDLINES - 1));
         if ((x > xmax) || (x < 0) || (y > ymax) || (y < 0))
                 return(-1);
         else
@@ -310,10 +350,10 @@ void put_statligne(int x, int y, char *texte, chtype attrib)
                 while (*texte)
                         *ptw++ = (chtype)(unsigned char)*texte++ | attrib;
         }
-        while (ptw < buffer + COLS)
+        while (ptw < buffer + JEREDCOLS)
                 *ptw++ = (chtype)' ' | attrib;
 
-        put_txt(x, y, (COLS - 1), y, buffer);
+        put_txt(x, y, (JEREDCOLS - 1), y, buffer);
 }
 /**********************************************************************/
 void put_helpline(int x, int y, char *texte, chtype attrib)
@@ -339,10 +379,10 @@ void put_helpline(int x, int y, char *texte, chtype attrib)
                         *ptw++ = (chtype)(unsigned char)*texte++ | a;
                 }
         }
-        while (ptw < buffer + COLS)
+        while (ptw < buffer + JEREDCOLS)
                 *ptw++ = (chtype)' ' | attrib;
 
-        put_txt(x, y, (COLS - 1), y, buffer);
+        put_txt(x, y, (JEREDCOLS - 1), y, buffer);
 }
 /**********************************************************************/
 void print_ligne(LIGNE *courante, int y, char *texte, int decalage)
@@ -362,7 +402,7 @@ void print_ligne(LIGNE *courante, int y, char *texte, int decalage)
                 while (*texte)
                         *ptw++ = (chtype)(unsigned char)*texte++ | coul;
         }
-        while (ptw <= buffer + COLS + decalage)
+        while (ptw <= buffer + JEREDCOLS + decalage)
                 *ptw++ = (chtype)' ' | coul;
 
         put_txt(XMIN, y, XMAX, y, buffer + decalage);
