@@ -314,11 +314,11 @@ void remap_a_key(char *mapping)
         }
 }
 /**********************************************************************/
-void mapkeynametofuncmactxt(char *keyname, char *funcmactxtname)
+void mapkeynametofuncmactxt(char *jkeyname, char *funcmactxtname)
 {
         int kindex;
 
-        kindex = key_index(keyname);
+        kindex = jkey_index(jkeyname);
         mapkeyindextofuncmactxt(kindex, funcmactxtname);
 }
 /**********************************************************************/
