@@ -24,7 +24,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include <string.h>
 #include <ctype.h>
 #include "jered.h"
 #include "formulr.h"
@@ -256,7 +255,7 @@ void centre_formulaire(PTFORMU form)
         int maxlig;
         PTFZONE zone;
 
-        maxlig = (LINES - 1);
+        maxlig = (JEREDLINES - 1);
 
         /* si une des zones du formulaire a une aide en ligne */
         /* on utilise une ligne de plus en bas */
@@ -275,7 +274,7 @@ void centre_formulaire(PTFORMU form)
                 form->y = 0;
 
         /* calcul de l'abscisse du formulaire pour qu'il soit centre */
-        form->x = ((COLS / 2) - (form->l + (form->l & 1)) / 2);
+        form->x = ((JEREDCOLS / 2) - (form->l + (form->l & 1)) / 2);
         if (form->x < 0)
                 form->x = 0;
 } 
@@ -395,7 +394,7 @@ int ouvre_formulaire(PTFORMU form)
                 first = 0;
         }
 
-        form->ligaide = (LINES - 2);
+        form->ligaide = (JEREDLINES - 2);
         
         /* si le formulaire courant est deja ouvert on sort */
         if (form->prepa != NULL || form->sauve != NULL)
@@ -598,18 +597,17 @@ int lire_formulaire(PTFORMU form)
 
         if (! entree)           /* si toutes les zones sont en sortie */
         {
-                        /* on attend une touche pendant 5 minutes (300 sec) */
                 do
                 {
                         form->lastkey = touche = fread_key();
                 }
-                while ((touche != KEY_ESCAPE) && (touche != Ctrl_G)) ;
+                while (touche != KEY_ESCAPE) ;
 
                 inputmode = NORMALMODE;
                 if (resizewin)
                         restart_screen_again();
                 
-                if ((touche == KEY_ESCAPE) || (touche == Ctrl_G))
+                if (touche == KEY_ESCAPE)
                         return(CANCELBUTTON);
                 else
                         return(OKBUTTON);
@@ -867,12 +865,7 @@ int valide_zone(PTFZONE zone)
 /**********************************************************************/
 static int compare_num(char *n1, char *n2)
 {
-        long l1, l2;        /* nombres a comparer */
-
-        l1 = atol(n1);
-        l2 = atol(n2);
-
-        return((int)(l1 - l2));
+        return((int)(atol(n1) - atol(n2)));
 }
 /**********************************************************************/
 static int homogene(PTFZONE zone)
@@ -950,6 +943,7 @@ int valide_caractere(char carac, char fmt)
                                                 retcode = 1;
                                         break;
                                         
+                                                /* KYLL         EI */
                                 case FINNISH:
                                         if ((carac == 'K') || (carac == 'E'))
                                                 retcode = 1;
@@ -973,7 +967,7 @@ int valide_caractere(char carac, char fmt)
                         }
                         break;
 
-                /* format oui/non */
+                /* format oui/non: french only */
                 case OUINON:
                         if (carac == 'O' || carac == 'N')
                                 retcode = 1;
@@ -985,12 +979,12 @@ int valide_caractere(char carac, char fmt)
                                 retcode = 1;
                         break;
 
-                /* format hexadecimal minuscule */
+                /* format hexadecimal minuscule/MAJUSCULE indifferenties */
                 case LHEXA:
-                        if ((carac >= '0' && carac <= '9') || (carac >= 'a' && carac <= 'f') || (carac >= 'A' && carac <= 'F'))
+                        if (isxdigit(carac))
                                 retcode = 1;
                         break;
-
+                        
                 /* format ascii libre */
                 case ASCNORM:
                         retcode = 1;
@@ -1003,7 +997,7 @@ int valide_caractere(char carac, char fmt)
 
                 /* format numerique seulement */
                 case NUMERIC:
-                        if (carac >= '0' && carac <= '9')
+                        if (isdigit(carac))
                                 retcode = 1;
                         break;
 
@@ -1080,20 +1074,20 @@ int lire_zone(PTFORMU form, PTFZONE zone)
         /* si il y a de l'aide en ligne alors on sauve le fond de l'ecran dessous */
         if (zone->aidenlig != NULL)
         {
-                bufecr =  (chtype *)malloc((COLS + 2) * sizeof(chtype));
+                bufecr =  (chtype *)malloc((JEREDCOLS + 2) * sizeof(chtype));
                 if (bufecr != NULL) /* we try to continue to work if bufecr == NULL */
                 {
                         /* sauve fond d'ecran */
-                        get_txt(0, form->ligaide, (COLS - 1), form->ligaide, bufecr);
+                        get_txt(0, form->ligaide, (JEREDCOLS - 1), form->ligaide, bufecr);
 
-                        newbuf = (char *)malloc(COLS + 2);
+                        newbuf = (char *)malloc(JEREDCOLS + 2);
                         if (newbuf != NULL)
                         {
                                 /* remplit buffer avec message + espaces */
                                 strcpy(newbuf, zone->aidenlig);
                                 lgaide = strlen(newbuf);
-                                memset(newbuf + lgaide, ' ', COLS - lgaide);
-                                *(newbuf + COLS) = '\0';
+                                memset(newbuf + lgaide, ' ', JEREDCOLS - lgaide);
+                                *(newbuf + JEREDCOLS) = '\0';
 
                                 /* affiche l'aide en ligne de la zone courante */
                                 put_statligne(0, form->ligaide, newbuf, zone->aidecolor);
@@ -1145,7 +1139,6 @@ int lire_zone(PTFORMU form, PTFZONE zone)
                 switch (touche)
                 {
                         case KEY_ESCAPE:
-                        case Ctrl_G:
                                 /* si action a realiser on la fait */
                                 if (zone->actioncar != NULL)
                                         zone->actioncar(form, zone);
@@ -1330,7 +1323,7 @@ int lire_zone(PTFORMU form, PTFZONE zone)
         {
                 if (bufecr != NULL)
                 {
-                        put_txt(0, form->ligaide, COLS - 1, form->ligaide, bufecr);
+                        put_txt(0, form->ligaide, JEREDCOLS - 1, form->ligaide, bufecr);
                         free(bufecr);
                 }
         }
