@@ -54,6 +54,8 @@
 #endif /* WIFEXITED */
 
 #include <signal.h>
+#include <pwd.h>
+#include <sys/types.h>
 #include "jered.h"
 #include "formulr.h"
 #include "mappable.h"
@@ -89,6 +91,8 @@ int macro = NOMACRO;            /* etat de la macro eventuelle */
                                 /* state of the macro possible ??? */
 FILE *fmacro = NULL;            /* pointeur vers le  fichier de macro */
                                 /* pointer  to   the file    of macro */
+int JEREDCOLS;                                
+int JEREDLINES;
 int XMAX;                       /* abscisse maxi du texte */
                                 /* height <abscissa> maximum of the text */
 int YMAX;                       /* ordonnee maxi du texte */
@@ -114,6 +118,7 @@ extern char vachercher[42];     /* variable in which string to find will be type
 extern char vremplacer[42];     /* variable in which replace string will be typed in */
 extern char vignorer[2];        /* variable in which ignore case Y/N will be typed in */
 
+void load_profile(void);
 void reset_alarm_handler(void); /* prototype declarations */
 void stop_alarm_handler(void);
 void do_autosave(int sig);
@@ -151,25 +156,13 @@ int main(int argc, char **argv)  /* JE starts here */
 {
         int retcode = 0;        /* code de retour */
                                 /* code of return */
-        char *profilename;      /* nom du fichier profile */
-                                /* name of the file profile */
-        char *mess;             /* message */
-
-#ifdef LIBC_BUG
-                /* Bernhard Rosenkraenzer - bero@in-trier.de / root@startrek.in-trier.de */
-                /* Fix for a very strange bug in some versions of glibc 2.
-                   For some reason, it seems to fail allocating memory for
-                   the argv[] pointers, and defining some string array
-                   helps??? */
-        char *this_should_not_help_but_it_does[4];
-#endif
 
         if ((argc < 2) || ((argc == 2) && ((! strcmp(argv[1], "--version")) || (! strcmp(argv[1], "-h"))
          || (! strcmp(argv[1], "-?")) || (! strcmp(argv[1], "--help")))))
         {
                 /*
-                        If the user did not type any filename on the command line, or type 'je -h'
-                        or 'je -?' or 'je --help' or type 'je --version', then the copyright notice
+                        If the user did not type any filename on the command line, or type 'jered -h'
+                        or 'jered -?' or 'jered --help' or type 'jered --version', then the copyright notice
                         is written on stdout and the program exits with a code of 0.
                 */
                 fprintf(stdout, usage, VERSION);
@@ -182,18 +175,8 @@ int main(int argc, char **argv)  /* JE starts here */
         */
         debute_ecran(); /* debute_ecran <> begin_screen */
 
-        /*
-                The environment variable JEPROFILE is used to retrieve the user settings file-
-                name. this name is sent to the function initialise_profile() in the file
-                'COULEURS.C'
-                This functions performs color and other user settings initialisation reading
-                the profile (for example 'PROFILE.JE') file if it exists or according to the
-                compile time settings.
-        */
-        profilename = (char *)getenv("JEPROFILE"); /* get the name of the profile file */
-        if (profilename == NULL)
-                profilename = "profile.je";
-        initialise_profile(profilename);
+        /* process the user's preferences */
+        load_profile();
 
         move(0, 0);             /* curses call to move the cursor to the top left corner */
         printw("%s", message[MSG_PLEASEWAIT]); /* curses call to display Please wait */
@@ -309,11 +292,51 @@ int main(int argc, char **argv)  /* JE starts here */
 
         termine_ecran(); /* terminate_display */
 
-        system("tput init");
+        system("tput init"); /* solves some problems on some terminals */
         
         exit(retcode);
 }
 /**********************************************************************/
+void load_profile(void)
+{
+        struct passwd *pw;
+        char *envprofilename;
+        char profilename[1024];
+        char *sysprofilename = "/etc/jeredrc";
+        char commande[2048];
+        
+        envprofilename = (char *)getenv("JEPROFILE");
+        if (envprofilename == NULL)
+        {        
+                /* pas de variable prdfinie donc on cherche le fichier ~/.jeredrc */
+                pw = getpwuid(getuid());
+                if (pw != NULL)
+                        sprintf(profilename, "%s/.jeredrc", pw->pw_dir);
+                else        
+                {
+                        /* erreur bizarre */
+                        /* on essaie de charger sans le copier le fichier /etc/jeredrc */
+                        strcpy(profilename, sysprofilename);
+                }
+        } 
+        else
+                strcpy(profilename, envprofilename);
+        
+        /* si le profile n'existe pas a l'endroit specifi alors on le cre */
+        /* en recopiant le fichier profile systme */
+        if (access(profilename, R_OK))
+        {
+                /* on ne recopie que si le fichier  crer n'est pas le profile systeme */
+                if (strcmp(sysprofilename, profilename))
+                {
+                        /* on espere que la commande cp est dans le PATH */
+                        sprintf(commande, "cp %s %s", sysprofilename, profilename);
+                        system(commande);
+                }           
+        }
+        initialise_profile(profilename);
+}
+/**********************************************************************/
 int edite_autre_fichier(char *filename) /* edite_autre_fichier <> edit_other_file */
 {
         int retcode = -1;               /* code de retour */
@@ -491,7 +514,7 @@ int sauvegarder(FICHIER *fichier, int isautosave) /* backup(FICHIER *file, int i
                 strcpy(tmp, message[MSG_SAVING]);
         }
         beautify_filename(tmp, fichier->filename);
-        put_statligne(0, (LINES - 1), tmp, couleur[COULEUR_AIDE]);
+        put_statligne(0, (JEREDLINES - 1), tmp, couleur[COULEUR_AIDE]);
 
         /* si copie de sauvegarde on essaie de l'effectuer */
         if (backup == OUI)
@@ -861,8 +884,8 @@ void chercher_remplacer(FICHIER *fichier)
                         {
                                 /* affiche l'ecran et place le curseur sous la chaine trouvee */
                                 diff = (int)(ptrouve - fichier->courante->texte);
-                                fichier->premier_caractere = (diff / COLS) * COLS;
-                                fichier->colonne = (diff % COLS);
+                                fichier->premier_caractere = (diff / JEREDCOLS) * JEREDCOLS;
+                                fichier->colonne = (diff % JEREDCOLS);
                                 fichier->affiche_ligne(fichier->courante, fichier->ligne, fichier->courante->texte, fichier->premier_caractere);
                                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
                                 affiche_status_line(fichier, diff + 1);
@@ -877,7 +900,7 @@ void chercher_remplacer(FICHIER *fichier)
                                 touche = 0; /* evite warning */
                                 if (! tous)
                                 {
-                                        touche = question();
+                                        touche = askquestion();
                                         if (touche == 'A')
                                                 tous = 1;
                                 }
@@ -1481,7 +1504,7 @@ int saisir_ligne(FICHIER *fichier)
                 i--;
         }
         fichier->affiche_ligne(fichier->courante, fichier->ligne, buffer, fichier->premier_caractere);
-        if ((fichier->colonne + fichier->premier_caractere) > (COLS - 1))
+        if ((fichier->colonne + fichier->premier_caractere) > (JEREDCOLS - 1))
                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
         set_refresh(ON);
         refresh();
@@ -1563,7 +1586,7 @@ int handle_normal_char(int key, FICHIER *fichier, char *buf, int position)
                         *(buf + SZBUF) = '\0';
 
                         droite(fichier, buf, 1, 0);
-                        if (fichier->colonne + fichier->premier_caractere > (COLS - 1))
+                        if (fichier->colonne + fichier->premier_caractere > (JEREDCOLS - 1))
                                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
                 }
         }
@@ -1853,7 +1876,7 @@ void current_word(char *buffer, int position, char *dest)
         *ptw = '\0';
 }
 /**********************************************************************/
-void launch_external_command(char *vcmdline, int wait)
+void launch_external_command(char *jvcmdline, int mustwait)
 {
         chtype *buffer;
         
@@ -1865,8 +1888,8 @@ void launch_external_command(char *vcmdline, int wait)
         buffer = sauve_ecran();
         if (buffer != NULL)
         {
-                system(vcmdline);
-                restaure_ecran(buffer, wait);
+                system(jvcmdline);
+                restaure_ecran(buffer, mustwait);
         }
         
         /* we can re-activate the autosave function */
